(raise e)(raise e id)(rescue f)(rescue f id)A macro that wraps exceptions in try/catch and emits a tuple (vector) instead of throwing
A macro that wraps exceptions in try/catch and emits a tuple (vector) instead of throwing
(try* f)try* is the same as rescue except it catches any Exception
try* is the same as rescue except it catches any Exception
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |